#ifndef XMALLOC0_H
#define XMALLOC0_H

#include <stdio.h>
#include <stdlib.h>

/* 関数プロトタイプ */
static inline void * xmalloc0(const size_t size)  __attribute__((always_inline));

/*******************************************************************************
 * callocのラッパー関数
*******************************************************************************/
static inline void * xmalloc0(const size_t size)
{
	void *p = calloc(1, size);

	if(!p)
	{
		perror("malloc");
		exit(EXIT_FAILURE);
	}

	return p;
}

#endif
